% FB_denoise_surelet: Denoising function using FB-Sure-Let-S method.
% dataR=FB_denoise_surelet(dataB,sigma,optionparam)
%
% FB_denoise_surelet: This function performs the denoising of an image,
% dataB, corrupted by Gaussian white noise with standard deviation sigma.
% optionparam is a structure with all the parameters needed for the method
% (optional, for default values see initSureletParam).
%
% Example :
%  data=double(imread('barbara.gif'));
%  sigma=30;
%  b=randn(256,256);
%  dataB=data+sigma*b/std(b(:));
%  dataR=FB_denoise_surelet(dataB,sigma);
%  figure(1); imagesc(data); colormap gray
%  figure(2); imagesc(dataB); colormap gray
%  figure(3); imagesc(dataR); colormap gray
% 
% See also FBSURELETS_EXT, INITSURELETPARAM.
%
% Input:        dataB (array of double), sigma (double)
% Optional:     optionparam (structure)
% Output:       dataR (array of double)
% Uses:         initSureletTnsf, initSureletParam, initMask, FBsureletS_ext
% Used in:
% Comments:
% Notes:
% Created:      2008/10/02
% Modified:     
%
%   Author: Jrme Gauthier, jerome.gauthier@gmail.com
